==> v0.6.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/util/transport/TransportAddressSerializers.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.util.transport;

import com.google.common.collect.ImmutableMap;
import org.elasticsearch.ElasticSearchIllegalStateException;
import org.elasticsearch.util.io.stream.StreamInput;
import org.elasticsearch.util.io.stream.StreamOutput;
import org.elasticsearch.util.logging.Loggers;
import org.slf4j.Logger;

import java.io.IOException;
import java.lang.reflect.Constructor;

import static org.elasticsearch.util.MapBuilder.*;

/**
 * A global registry of all different types of {@link org.elasticsearch.util.transport.TransportAddress} allowing
 * to perfrom serialization of them.
 * <p/>
 * <p>By defualt, adds {@link org.elasticsearch.util.transport.InetSocketTransportAddress}.
 *
 * @author kimchy (Shay Banon)
 */
public abstract class TransportAddressSerializers {

    private static final Logger logger = Loggers.getLogger(TransportAddressSerializers.class);

    private static ImmutableMap<Short, Constructor<? extends TransportAddress>> addressConstructors = ImmutableMap.of();

    static {
        try {
            addAddressType(DummyTransportAddress.INSTANCE);
            addAddressType(new InetSocketTransportAddress());
            addAddressType(new LocalTransportAddress());
        } catch (Exception e) {
            logger.warn("Failed to add InetSocketTransportAddress", e);
        }
    }

    public static synchronized void addAddressType(TransportAddress address) throws Exception {
        if (addressConstructors.containsKey(address.uniqueAddressTypeId())) {
            throw new ElasticSearchIllegalStateException("Address [" + address.uniqueAddressTypeId() + "] already bound");
        }
        Constructor<? extends TransportAddress> constructor = address.getClass().getDeclaredConstructor();
        constructor.setAccessible(true);
        addressConstructors = newMapBuilder(addressConstructors).put(address.uniqueAddressTypeId(), constructor).immutableMap();
    }

    public static TransportAddress addressFromStream(StreamInput input) throws IOException {
        short addressUniqueId = input.readShort();
        Constructor<? extends TransportAddress> constructor = addressConstructors.get(addressUniqueId);
        if (constructor == null) {
            throw new IOException("No transport address mapped to [" + addressUniqueId + "]");
        }
        TransportAddress address;
        try {
            address = constructor.newInstance();
        } catch (Exception e) {
            throw new IOException("Failed to create class with constructor [" + constructor + "]", e);
        }
        address.readFrom(input);
        return address;
    }

    public static void addressToStream(StreamOutput out, TransportAddress address) throws IOException {
        out.writeShort(address.uniqueAddressTypeId());
        address.writeTo(out);
    }
}

==> v0.7.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/util/transport/TransportAddressSerializers.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.util.transport;

import org.elasticsearch.ElasticSearchIllegalStateException;
import org.elasticsearch.util.collect.ImmutableMap;
import org.elasticsearch.util.io.stream.StreamInput;
import org.elasticsearch.util.io.stream.StreamOutput;
import org.elasticsearch.util.logging.ESLogger;
import org.elasticsearch.util.logging.Loggers;

import java.io.IOException;
import java.lang.reflect.Constructor;

import static org.elasticsearch.util.MapBuilder.*;

/**
 * A global registry of all different types of {@link org.elasticsearch.util.transport.TransportAddress} allowing
 * to perform serialization of them.
 *
 * <p>By default, adds {@link org.elasticsearch.util.transport.InetSocketTransportAddress}.
 *
 * @author kimchy (Shay Banon)
 */
public abstract class TransportAddressSerializers {

    private static final ESLogger logger = Loggers.getLogger(TransportAddressSerializers.class);

    private static ImmutableMap<Short, Constructor<? extends TransportAddress>> addressConstructors = ImmutableMap.of();

    static {
        try {
            addAddressType(DummyTransportAddress.INSTANCE);
            addAddressType(new InetSocketTransportAddress());
            addAddressType(new LocalTransportAddress());
        } catch (Exception e) {
            logger.warn("Failed to add InetSocketTransportAddress", e);
        }
    }

    public static synchronized void addAddressType(TransportAddress address) throws Exception {
        if (addressConstructors.containsKey(address.uniqueAddressTypeId())) {
            throw new ElasticSearchIllegalStateException("Address [" + address.uniqueAddressTypeId() + "] already bound");
        }
        Constructor<? extends TransportAddress> constructor = address.getClass().getDeclaredConstructor();
        constructor.setAccessible(true);
        addressConstructors = newMapBuilder(addressConstructors).put(address.uniqueAddressTypeId(), constructor).immutableMap();
    }

    public static TransportAddress addressFromStream(StreamInput input) throws IOException {
        short addressUniqueId = input.readShort();
        Constructor<? extends TransportAddress> constructor = addressConstructors.get(addressUniqueId);
        if (constructor == null) {
            throw new IOException("No transport address mapped to [" + addressUniqueId + "]");
        }
        TransportAddress address;
        try {
            address = constructor.newInstance();
        } catch (Exception e) {
            throw new IOException("Failed to create class with constructor [" + constructor + "]", e);
        }
        address.readFrom(input);
        return address;
    }

    public static void addressToStream(StreamOutput out, TransportAddress address) throws IOException {
        out.writeShort(address.uniqueAddressTypeId());
        address.writeTo(out);
    }
}
